# How to cite HappyFeat

When citing *HappyFeat*, please also cite the journal article reference:

Desbois, Arthur and Venot, Tristan and De Vico Fallani, Fabrizio and Corsi, Marie-Constance (2024). **HappyFeat—An interactive and efficient BCI framework for clinical applications**. *Software Impacts*, 19, 100610. ISSN: 2665-9638. [https://doi.org/10.1016/j.simpa.2023.100610](https://doi.org/10.1016/j.simpa.2023.100610)

!!! BibTeX 
    ```
    @article{desbois_happyfeatinteractive_2024,
	    title = {HappyFeat—An interactive and efficient BCI framework for clinical applications},
            author = {Desbois, Arthur and Venot, Tristan and De Vico Fallani, Fabrizio and Corsi, Marie-Constance},
	    volume = {19},
            month = mar,
	    year = {2024},
	    pages = {100610},
	    issn = {2665-9638},
	    doi = {10.1016/j.simpa.2023.100610},
	    journal = {Software Impacts},
    }
    ```
